import time


def parse_commiter_line(line):
    #print(line)
    #print("~")
    "Parse the commiter/author line which also contains a datetime"
    parts = line.split()
    # TODO: I'll ignore tz for now It is parts[:-1]
    unix_time = float(parts[-2])
    commiter = " ".join(parts[1:-2])
    commit_time = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(unix_time))
    return commiter, commit_time


def parse_git_message(data, gi):
    lines = data.decode("utf-8").split("\n")
    reading_pgp = False
    reading_msg = False
    for idx, l in enumerate(lines):
        if l == "" and not reading_msg:
            reading_pgp = False
            reading_msg = True
            continue

        if reading_pgp == True:
            continue

        if reading_msg == True:
            gi["message"] += l
            if not l and idx < len(lines)-1:
                gi['message']+='\n'

        if l.startswith("tree"):
            gi["tree"] = l.split()[1]
        elif l.startswith("parent"):
            gi["parent"] = l.split()[1]
        elif l.startswith("gpgsig"):
            reading_pgp = True
        elif l.startswith("commiter"):
            commiter, commit_time = parse_commiter_line(l)
            gi["commiter"] = commiter
            gi["commit_date"] = commit_time
        elif l.startswith("author"):
            author, author_time = parse_commiter_line(l)
            gi["author"] = author
            gi["author_date"] = author_time

    return gi



#!/usr/bin/env python
from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='python-git-info',
    version='0.7.2',
    description='Get git information repository, directly from .git',

    author='Serafeim Papastefanos',
    author_email='spapas@gmail.com',
    license='MIT',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/spapas/python-git-info/',
    zip_safe=False,
    include_package_data=False,
    packages=find_packages(exclude=['tests.*', 'tests', 'sample', ]),

    classifiers=[
        'Environment :: Web Environment',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Version Control :: Git',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
